@@ -50,7 +50,6 @@ static void g_mime_message_init (GMimeMessage *message, GMimeMessageClass *klass
 static void g_mime_message_finalize (GObject *object);
 
 /* GMimeObject class methods */
-static void message_init (GMimeObject *object);
 static void message_prepend_header (GMimeObject *object, const char *header, const char *value);
 static void message_append_header (GMimeObject *object, const char *header, const char *value);
 static void message_set_header (GMimeObject *object, const char *header, const char *value);
@@ -59,7 +58,7 @@ static gboolean message_remove_header (GMimeObject *object, const char *header);
 static char *message_get_headers (GMimeObject *object);
 static ssize_t message_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
-static void message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str);
+static void message_add_recipients_from_string (GMimeMessage *message, GMimeRecipientType type, const char *str);
 
 static ssize_t write_structured (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_addrspec (GMimeStream *stream, const char *name, const char *value);
@@ -70,6 +69,11 @@ static ssize_t write_msgid (GMimeStream *stream, const char *name, const char *v
 
 static GMimeObjectClass *parent_class = NULL;
 
+static const char *recipient_types[] = {
+	"To", "Cc", "Bcc"
+};
+
+#define N_RECIPIENT_TYPES G_N_ELEMENTS (recipient_types)
 
 static char *rfc822_headers[] = {
 	"Return-Path",
@@ -119,7 +123,6 @@ g_mime_message_class_init (GMimeMessageClass *klass)
 	
 	gobject_class->finalize = g_mime_message_finalize;
 	
-	object_class->init = message_init;
 	object_class->prepend_header = message_prepend_header;
 	object_class->append_header = message_append_header;
 	object_class->remove_header = message_remove_header;
@@ -139,7 +142,7 @@ g_mime_message_init (GMimeMessage *message, GMimeMessageClass *klass)
 	message->recipients = g_hash_table_new (g_str_hash, g_str_equal);
 	message->subject = NULL;
 	message->date = 0;
-	message->gmt_offset = 0;
+	message->tz_offset = 0;
 	message->message_id = NULL;
 	message->mime_part = NULL;
 	
@@ -195,15 +198,7 @@ g_mime_message_finalize (GObject *object)
 }
 
 
-static void
-message_init (GMimeObject *object)
-{
-	/* no-op */
-	GMIME_OBJECT_CLASS (parent_class)->init (object);
-}
-
-
-typedef void (*token_skip_t) (const char **in);
+typedef void (* token_skip_t) (const char **in);
 
 struct _received_token {
 	char *token;
@@ -666,7 +661,7 @@ process_header (GMimeObject *object, const char *header, const char *value)
 		if (value) {
 			date = g_mime_utils_header_decode_date (value, &offset);
 			message->date = date;
-			message->gmt_offset = offset;
+			message->tz_offset = offset;
 		}
 		break;
 	case HEADER_MESSAGE_ID:
@@ -769,6 +764,7 @@ message_remove_header (GMimeObject *object, const char *header)
 {
 	GMimeMessage *message = (GMimeMessage *) object;
 	InternetAddressList *addrlist;
+	const char *type;
 	int i;
 	
 	if (!g_ascii_strcasecmp ("MIME-Version", header))
@@ -798,18 +794,21 @@ message_remove_header (GMimeObject *object, const char *header)
 		message->reply_to = NULL;
 		break;
 	case HEADER_TO:
-		addrlist = g_hash_table_lookup (message->recipients, GMIME_RECIPIENT_TYPE_TO);
-		g_hash_table_remove (message->recipients, GMIME_RECIPIENT_TYPE_TO);
+		type = recipient_types[GMIME_RECIPIENT_TYPE_TO];
+		addrlist = g_hash_table_lookup (message->recipients, type);
+		g_hash_table_remove (message->recipients, type);
 		internet_address_list_destroy (addrlist);
 		break;
 	case HEADER_CC:
-		addrlist = g_hash_table_lookup (message->recipients, GMIME_RECIPIENT_TYPE_CC);
-		g_hash_table_remove (message->recipients, GMIME_RECIPIENT_TYPE_CC);
+		type = recipient_types[GMIME_RECIPIENT_TYPE_CC];
+		addrlist = g_hash_table_lookup (message->recipients, type);
+		g_hash_table_remove (message->recipients, type);
 		internet_address_list_destroy (addrlist);
 		break;
 	case HEADER_BCC:
-		addrlist = g_hash_table_lookup (message->recipients, GMIME_RECIPIENT_TYPE_BCC);
-		g_hash_table_remove (message->recipients, GMIME_RECIPIENT_TYPE_BCC);
+		type = recipient_types[GMIME_RECIPIENT_TYPE_BCC];
+		addrlist = g_hash_table_lookup (message->recipients, type);
+		g_hash_table_remove (message->recipients, type);
 		internet_address_list_destroy (addrlist);
 		break;
 	case HEADER_SUBJECT:
@@ -818,7 +817,7 @@ message_remove_header (GMimeObject *object, const char *header)
 		break;
 	case HEADER_DATE:
 		message->date = 0;
-		message->gmt_offset = 0;
+		message->tz_offset = 0;
 		break;
 	case HEADER_MESSAGE_ID:
 		g_free (message->message_id);
@@ -1020,90 +1019,86 @@ g_mime_message_get_reply_to (GMimeMessage *message)
 
 
 static void
-sync_recipient_header (GMimeMessage *message, const char *type)
+sync_recipient_header (GMimeMessage *message, GMimeRecipientType type)
 {
+	const char *name = recipient_types[type];
 	const InternetAddressList *recipients;
 	char *string;
 	
 	/* sync the specified recipient header */
 	if ((recipients = g_mime_message_get_recipients (message, type))) {
 		string = internet_address_list_to_string (recipients, TRUE);
-		g_mime_header_list_set (GMIME_OBJECT (message)->headers, type, string);
+		g_mime_header_list_set (GMIME_OBJECT (message)->headers, name, string);
 		g_free (string);
 	} else
-		g_mime_header_list_set (GMIME_OBJECT (message)->headers, type, NULL);
+		g_mime_header_list_set (GMIME_OBJECT (message)->headers, name, NULL);
 }
 
 
 /**
  * g_mime_message_add_recipient:
  * @message: MIME Message to change
- * @type: Recipient type
+ * @type: A #GMimeRecipientType
  * @name: The recipient's name
  * @address: The recipient's address
  *
- * Add a recipient of a chosen type to the MIME Message. Available
- * recipient types include: #GMIME_RECIPIENT_TYPE_TO,
- * #GMIME_RECIPIENT_TYPE_CC and #GMIME_RECIPIENT_TYPE_BCC.
+ * Add a recipient of a chosen type to the MIME Message.
  **/
 void
-g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address)
+g_mime_message_add_recipient (GMimeMessage *message, GMimeRecipientType type, const char *name, const char *address)
 {
 	InternetAddressList *recipients;
 	InternetAddress *ia;
 	
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
-	g_return_if_fail (type != NULL);
+	g_return_if_fail (type < N_RECIPIENT_TYPES);
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (address != NULL);
 	
 	ia = internet_address_new_name (name, address);
 	
-	recipients = g_hash_table_lookup (message->recipients, type);
-	g_hash_table_remove (message->recipients, type);
+	recipients = g_hash_table_lookup (message->recipients, recipient_types[type]);
+	g_hash_table_remove (message->recipients, recipient_types[type]);
 	
 	recipients = internet_address_list_append (recipients, ia);
 	internet_address_unref (ia);
 	
-	g_hash_table_insert (message->recipients, type, recipients);
+	g_hash_table_insert (message->recipients, (char *) recipient_types[type], recipients);
 	sync_recipient_header (message, type);
 }
 
 
 static void
-message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str)
+message_add_recipients_from_string (GMimeMessage *message, GMimeRecipientType type, const char *str)
 {
 	InternetAddressList *recipients, *addrlist;
 	
-	recipients = g_hash_table_lookup (message->recipients, type);
-	g_hash_table_remove (message->recipients, type);
+	recipients = g_hash_table_lookup (message->recipients, recipient_types[type]);
+	g_hash_table_remove (message->recipients, recipient_types[type]);
 	
 	if ((addrlist = internet_address_parse_string (str))) {
 		recipients = internet_address_list_concat (recipients, addrlist);
 		internet_address_list_destroy (addrlist);
 	}
 	
-	g_hash_table_insert (message->recipients, type, recipients);
+	g_hash_table_insert (message->recipients, (char *) recipient_types[type], recipients);
 }
 
 
 /**
  * g_mime_message_add_recipients_from_string:
  * @message: MIME Message
- * @type: Recipient type
+ * @type: A #GMimeRecipientType
  * @str: A string of recipient names and addresses.
  *
- * Add a list of recipients of a chosen type to the MIME
- * Message. Available recipient types include:
- * #GMIME_RECIPIENT_TYPE_TO, #GMIME_RECIPIENT_TYPE_CC and
- * #GMIME_RECIPIENT_TYPE_BCC. The string must be in the format
- * specified in rfc822.
+ * Add a list of recipients of a chosen type to the MIME Message. The
+ * string @str must be in the format specified in rfc822.
  **/
 void
-g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str)
+g_mime_message_add_recipients_from_string (GMimeMessage *message, GMimeRecipientType type, const char *str)
 {
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
-	g_return_if_fail (type != NULL);
+	g_return_if_fail (type < N_RECIPIENT_TYPES);
 	g_return_if_fail (str != NULL);
 	
 	message_add_recipients_from_string (message, type, str);
@@ -1115,31 +1110,23 @@ g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, co
 /**
  * g_mime_message_get_recipients:
  * @message: MIME Message
- * @type: Recipient type
+ * @type: A #GMimeRecipientType
  *
- * Gets a list of recipients of type @type from @message. Available
- * recipient types include: #GMIME_RECIPIENT_TYPE_TO,
- * #GMIME_RECIPIENT_TYPE_CC and #GMIME_RECIPIENT_TYPE_BCC.
+ * Gets a list of recipients of type @type from @message.
  *
  * Returns: a list of recipients of a chosen type from the MIME
  * Message.
  **/
 const InternetAddressList *
-g_mime_message_get_recipients (GMimeMessage *message, const char *type)
+g_mime_message_get_recipients (GMimeMessage *message, GMimeRecipientType type)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
-	g_return_val_if_fail (type != NULL, NULL);
+	g_return_val_if_fail (type < N_RECIPIENT_TYPES, NULL);
 	
-	return g_hash_table_lookup (message->recipients, type);
+	return g_hash_table_lookup (message->recipients, recipient_types[type]);
 }
 
 
-static const char *recipient_types[] = {
-	GMIME_RECIPIENT_TYPE_TO,
-	GMIME_RECIPIENT_TYPE_CC,
-	GMIME_RECIPIENT_TYPE_BCC
-};
-
 /**
  * g_mime_message_get_all_recipients:
  * @message: MIME Message
@@ -1222,68 +1209,90 @@ g_mime_message_get_subject (GMimeMessage *message)
 /**
  * g_mime_message_set_date:
  * @message: MIME Message
- * @date: Sent-date (ex: gotten from time (NULL))
- * @gmt_offset: GMT date offset (in +/- hours)
+ * @date: a date to be used in the Date header
+ * @tz_offset: timezone offset (in +/- hours)
  * 
- * Sets the sent-date on a MIME Message.
+ * Sets the Date header on a MIME Message.
  **/
 void
-g_mime_message_set_date (GMimeMessage *message, time_t date, int gmt_offset)
+g_mime_message_set_date (GMimeMessage *message, time_t date, int tz_offset)
 {
-	char *date_str;
+	char *str;
 	
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
 	
 	message->date = date;
-	message->gmt_offset = gmt_offset;
+	message->tz_offset = tz_offset;
 	
-	date_str = g_mime_message_get_date_string (message);
-	g_mime_object_set_header (GMIME_OBJECT (message), "Date", date_str);
-	g_free (date_str);
+	str = g_mime_utils_header_format_date (date, tz_offset);
+	g_mime_object_set_header (GMIME_OBJECT (message), "Date", str);
+	g_free (str);
 }
 
 
 /**
  * g_mime_message_get_date:
  * @message: MIME Message
- * @date: Sent-date
- * @gmt_offset: GMT date offset (in +/- hours)
+ * @date: pointer to a date in time_t
+ * @tz_offset: pointer to timezone offset (in +/- hours)
  * 
- * Stores the date in time_t format in #date and the GMT offset in
- * @gmt_offset.
+ * Stores the date in time_t format in @date. If @tz_offset is
+ * non-%NULL, then the timezone offset in will be stored in
+ * @tz_offset.
  **/
 void
-g_mime_message_get_date (GMimeMessage *message, time_t *date, int *gmt_offset)
+g_mime_message_get_date (GMimeMessage *message, time_t *date, int *tz_offset)
 {
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
 	g_return_if_fail (date != NULL);
 	
 	*date = message->date;
 	
-	if (gmt_offset)
-		*gmt_offset = message->gmt_offset;
+	if (tz_offset)
+		*tz_offset = message->tz_offset;
 }
 
 
 /**
- * g_mime_message_get_date_string:
+ * g_mime_message_get_date_as_string:
  * @message: MIME Message
  *
- * Gets the message's sent date in string format.
+ * Gets the message's sent-date in string format.
  * 
- * Returns: the sent-date of the MIME Message in string format.
+ * Returns: a newly allocated string containing the Date header value.
  **/
 char *
-g_mime_message_get_date_string (GMimeMessage *message)
+g_mime_message_get_date_as_string (GMimeMessage *message)
 {
-	char *date_str;
-	
 	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
 	
-	date_str = g_mime_utils_header_format_date (message->date,
-						    message->gmt_offset);
+	return g_mime_utils_header_format_date (message->date, message->tz_offset);
+}
+
+
+/**
+ * g_mime_message_set_date_as_string:
+ * @message: MIME Message
+ * @str: a date string
+ *
+ * Sets the sent-date of the message.
+ **/
+void
+g_mime_message_set_date_as_string (GMimeMessage *message, const char *str)
+{
+	int tz_offset;
+	time_t date;
+	char *buf;
 	
-	return date_str;
+	g_return_if_fail (GMIME_IS_MESSAGE (message));
+	
+	date = g_mime_utils_header_decode_date (str, &tz_offset);
+	message->tz_offset = tz_offset;
+	message->date = date;
+	
+	buf = g_mime_utils_header_format_date (date, tz_offset);
+	g_mime_object_set_header (GMIME_OBJECT (message), "Date", buf);
+	g_free (buf);
 }
 
 
