@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -59,7 +59,7 @@
  *
  * Creates a new #InternetAddress object
  * 
- * Returns a new #InternetAddress object.
+ * Returns: a new #InternetAddress object.
  **/
 InternetAddress *
 internet_address_new (void)
@@ -135,7 +135,7 @@ internet_address_unref (InternetAddress *ia)
  * Creates a new #InternetAddress object with name @name and address
  * @addr.
  * 
- * Returns a new #InternetAddress object.
+ * Returns: a new #InternetAddress object.
  **/
 InternetAddress *
 internet_address_new_name (const char *name, const char *addr)
@@ -162,7 +162,7 @@ internet_address_new_name (const char *name, const char *addr)
  *
  * Creates a new #InternetAddress object with group name @name.
  * 
- * Returns a new #InternetAddress object.
+ * Returns: a new #InternetAddress object.
  **/
 InternetAddress *
 internet_address_new_group (const char *name)
@@ -265,7 +265,7 @@ internet_address_add_member (InternetAddress *ia, InternetAddress *member)
  * Gets the type of the internet address, which will either be
  * #INTERNET_ADDRESS_NAME or #INTERNET_ADDRESS_GROUP.
  *
- * Returns the type of @ia.
+ * Returns: the type of @ia.
  **/
 InternetAddressType
 internet_address_get_type (InternetAddress *ia)
@@ -275,6 +275,7 @@ internet_address_get_type (InternetAddress *ia)
 	return ia->type;
 }
 
+
 /**
  * internet_address_get_name:
  * @ia: internet address
@@ -282,7 +283,7 @@ internet_address_get_type (InternetAddress *ia)
  * Gets the name component of the internet address. If the internet
  * address is a group, it will get the group name.
  *
- * Returns the name of @ia.
+ * Returns: the name of @ia.
  **/
 const char *
 internet_address_get_name (InternetAddress *ia)
@@ -299,7 +300,7 @@ internet_address_get_name (InternetAddress *ia)
  *
  * Gets the addr-spec of the internet address.
  *
- * Returns the address of @ia.
+ * Returns: the address of @ia.
  **/
 const char *
 internet_address_get_addr (InternetAddress *ia)
@@ -318,7 +319,7 @@ internet_address_get_addr (InternetAddress *ia)
  * Gets the #InternetAddressList containing the group members of an
  * rfc822 group address.
  *
- * Returns the members of @ia.
+ * Returns: the members of @ia.
  **/
 const InternetAddressList *
 internet_address_get_members (InternetAddress *ia)
@@ -338,7 +339,7 @@ internet_address_get_members (InternetAddress *ia)
  * Prepends the internet address @ia to the list of internet addresses
  * pointed to by @list.
  *
- * Returns the resultant list.
+ * Returns: the resultant list.
  **/
 InternetAddressList *
 internet_address_list_prepend (InternetAddressList *list, InternetAddress *ia)
@@ -364,7 +365,7 @@ internet_address_list_prepend (InternetAddressList *list, InternetAddress *ia)
  * Appends the internet address to the list of internet addresses
  * pointed to by @list.
  *
- * Returns the resultant list.
+ * Returns: the resultant list.
  **/
 InternetAddressList *
 internet_address_list_append (InternetAddressList *list, InternetAddress *ia)
@@ -398,7 +399,7 @@ internet_address_list_append (InternetAddressList *list, InternetAddress *ia)
  *
  * Concatenates a copy of list @b onto the end of list @a.
  *
- * Returns the resulting list.
+ * Returns: the resulting list.
  **/
 InternetAddressList *
 internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
@@ -440,7 +441,7 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
  *
  * Advances to the next address node in the #InternetAddessList.
  *
- * Returns the next address node in the #InternetAddessList.
+ * Returns: the next address node in the #InternetAddessList.
  **/
 InternetAddressList *
 internet_address_list_next (const InternetAddressList *list)
@@ -455,7 +456,7 @@ internet_address_list_next (const InternetAddressList *list)
  *
  * Gets the #InternetAddress currently pointed to in @list.
  *
- * Returns the #InternetAddress currently pointed to in @list.
+ * Returns: the #InternetAddress currently pointed to in @list.
  **/
 InternetAddress *
 internet_address_list_get_address (const InternetAddressList *list)
@@ -469,7 +470,7 @@ internet_address_list_get_address (const InternetAddressList *list)
  *
  * Calculates the length of the list of addresses.
  *
- * Returns the number of internet addresses in @list.
+ * Returns: the number of internet addresses in @list.
  **/
 int
 internet_address_list_length (const InternetAddressList *list)
@@ -700,7 +701,7 @@ _internet_address_list_to_string (const InternetAddressList *list, guint32 flags
  * Allocates a string containing the contents of the #InternetAddress
  * object.
  * 
- * Returns the #InternetAddress object as an allocated string in
+ * Returns: the #InternetAddress object as an allocated string in
  * rfc822 format.
  **/
 char *
@@ -729,7 +730,7 @@ internet_address_to_string (const InternetAddress *ia, gboolean encode)
  * Allocates a string buffer containing the rfc822 formatted addresses
  * in @list.
  *
- * Returns a string containing the list of addresses in rfc822 format.
+ * Returns: a string containing the list of addresses in rfc822 format.
  **/
 char *
 internet_address_list_to_string (const InternetAddressList *list, gboolean encode)
@@ -770,38 +771,42 @@ static InternetAddress *
 decode_mailbox (const char **in)
 {
 	InternetAddress *mailbox = NULL;
-	const char *inptr;
+	const char *inptr, *word;
 	gboolean bracket = FALSE;
 	GString *name = NULL;
 	GString *addr;
-	char *pre;
+	size_t n = 0;
 	
 	addr = g_string_new ("");
 	
 	decode_lwsp (in);
 	inptr = *in;
 	
-	pre = decode_word (&inptr);
+	if ((word = decode_word (&inptr)))
+		n = inptr - word;
+	
 	decode_lwsp (&inptr);
 	if (*inptr && !strchr (",.@", *inptr)) {
 		gboolean retried = FALSE;
 		
 		/* this mailbox has a name part, so get the name */
 		name = g_string_new ("");
-		while (pre) {
+		while (word) {
+			g_string_append_len (name, word, n);
 			retried = FALSE;
-			g_string_append (name, pre);
-			g_free (pre);
 		retry:
-			if ((pre = decode_word (&inptr)))
+			if ((word = decode_word (&inptr))) {
 				g_string_append_c (name, ' ');
+				n = inptr - word;
+			}
 		}
 		
 		decode_lwsp (&inptr);
 		if (*inptr == '<') {
 			inptr++;
 			bracket = TRUE;
-			pre = decode_word (&inptr);
+			if ((word = decode_word (&inptr)))
+				n = inptr - word;
 		} else if (!retried && *inptr) {
 			w(g_warning ("Unexpected char '%c' in mailbox: %s: attempting recovery.",
 				     *inptr, *in));
@@ -818,8 +823,8 @@ decode_mailbox (const char **in)
 		}
 	}
 	
-	if (pre) {
-		g_string_append (addr, pre);
+	if (word) {
+		g_string_append_len (addr, word, n);
 	} else {
 		w(g_warning ("No local part for email address: %s", *in));
 		if (name)
@@ -827,7 +832,7 @@ decode_mailbox (const char **in)
 		g_string_free (addr, TRUE);
 		
 		/* comma will be eaten by our caller */
-		if (*inptr != ',')
+		if (*inptr && *inptr != ',')
 			*in = inptr + 1;
 		else
 			*in = inptr;
@@ -837,16 +842,16 @@ decode_mailbox (const char **in)
 	
 	/* get the rest of the local-part */
 	decode_lwsp (&inptr);
-	while (*inptr == '.' && pre) {
+	while (*inptr == '.' && word) {
 		inptr++;
-		g_free (pre);
-		if ((pre = decode_word (&inptr))) {
+		
+		if ((word = decode_word (&inptr))) {
 			g_string_append_c (addr, '.');
-			g_string_append (addr, pre);
+			g_string_append_len (addr, word, inptr - word);
 		}
+		
 		decode_lwsp (&inptr);
 	}
-	g_free (pre);
 	
 	/* we should be at the '@' now... */
 	if (*inptr == '@') {
@@ -929,20 +934,19 @@ decode_address (const char **in)
 {
 	InternetAddress *addr = NULL;
 	const char *inptr, *start;
+	const char *word;
 	GString *name;
-	char *pre;
 	
 	decode_lwsp (in);
 	start = inptr = *in;
 	
 	/* pre-scan */
 	name = g_string_new ("");
-	pre = decode_word (&inptr);
-	while (pre) {
-		g_string_append (name, pre);
-		g_free (pre);
-		
-		if ((pre = decode_word (&inptr)))
+	word = decode_word (&inptr);
+	
+	while (word) {
+		g_string_append_len (name, word, inptr - word);
+		if ((word = decode_word (&inptr)))
 			g_string_append_c (name, ' ');
 	}
 	
@@ -1004,20 +1008,18 @@ decode_address (const char **in)
 
 /**
  * internet_address_parse_string:
- * @string: a string containing internet addresses
+ * @str: a string containing internet addresses
  *
  * Construct a list of internet addresses from the given string.
  *
- * Returns a linked list of internet addresses. *Must* be free'd by
+ * Returns: a linked list of internet addresses. *Must* be free'd by
  * the caller.
  **/
 InternetAddressList *
-internet_address_parse_string (const char *string)
+internet_address_parse_string (const char *str)
 {
 	InternetAddressList *node, *tail, *addrlist = NULL;
-	const char *inptr;
-	
-	inptr = string;
+	const char *inptr = str;
 	
 	tail = (InternetAddressList *) &addrlist;
 	
@@ -1026,7 +1028,6 @@ internet_address_parse_string (const char *string)
 		const char *start;
 		
 		start = inptr;
-		
 		addr = decode_address (&inptr);
 		
 		if (addr) {
